@@ -171,31 +171,34 @@ class ChatToConsole(object):
 
 registerAdapter(ChatToConsole, IChatCommand, IConsoleCommand)
 
-def recipe_invariant(r):
-    # Size invariant.
-    if len(r.recipe) != r.dimensions[0] * r.dimensions[1]:
-        raise InvariantException("Recipe size is invalid")
-
 class IRecipe(IBravoPlugin):
     """
-    Recipe for crafting materials from other materials.
+    A description for creating materials from other materials.
     """
 
-    invariant(recipe_invariant)
+    def matches(table, stride):
+        """
+        Determine whether a given crafting table matches this recipe.
 
-    dimensions = Attribute("""
-        Tuple representing the size of the recipe.
-        """)
+        ``table`` is a list of slots.
+        ``stride`` is the stride of the table.
 
-    recipe = Attribute("""
-        Tuple representing the items of the recipe.
+        :returns: bool
+        """
 
-        Recipes need to be filled out left-to-right, top-to-bottom, with one
-        of two things:
+    def reduce(table, stride):
+        """
+        Remove items from a given crafting table corresponding to a single
+        match of this recipe. The table is modified in-place.
 
-         * A tuple (slot, count) for the item/block that needs to be present;
-         * None, if the slot needs to be empty.
-        """)
+        This method is meant to be used to subtract items from a crafting
+        table following a successful recipe match.
+
+        This method may assume that this recipe ``matches()`` the table.
+
+        ``table`` is a list of slots.
+        ``stride`` is the stride of the table.
+        """
 
     provides = Attribute("""
         Tuple representing the yield of this recipe.
@@ -292,6 +295,46 @@ class ISerializerFactory(IBravoPlugin):
 
 # Hooks
 
+class IWindowOpenHook(ISortedPlugin):
+    """
+    Hook for actions to be taken on container open
+    """
+
+    def open_hook(player, container, block):
+        """
+        The ``player`` is a Player's protocol
+        The ``container`` is a 0x64 message
+        The ``block`` is a block we trying to open
+        :returns: ``Deffered`` with None or window object
+        """
+        pass
+
+class IWindowClickHook(ISortedPlugin):
+    """
+    Hook for actions to be taken on window clicks
+    """
+
+    def click_hook(player, container):
+        """
+        The ``player`` a Player's protocol
+        The ``container`` is a 0x66 message
+        :returns: True if you processed the action and TRANSACTION must be ok
+                  You probably will never return True here.
+        """
+        pass
+
+class IWindowCloseHook(ISortedPlugin):
+    """
+    Hook for actions to be taken on window clicks
+    """
+
+    def close_hook(player, container):
+        """
+        The ``player`` a Player's protocol
+        The ``container`` is a 0x65 message
+        """
+        pass
+
 class IPreBuildHook(ISortedPlugin):
     """
     Hook for actions to be taken before a block is placed.
@@ -316,24 +359,27 @@ class IPreBuildHook(ISortedPlugin):
 
         >>> from bravo.parameters import factory
 
-        The second variable in the return value indicates whether processing
+        First variable in the return value indicates whether processing
         of building should continue after this hook runs. Use it to halt build
         hook processing, if needed.
 
+        Third variable in the return value indicates whether building process
+        shall be canceled. Use it to completele stop the process.
+
         For sanity purposes, build hooks may return a ``Deferred`` which will
         fire with their return values, but are not obligated to do so.
 
         A trivial do-nothing build hook looks like the following:
 
         >>> def pre_build_hook(self, player, builddata):
-        ...     return True, builddata
+        ...     return True, builddata, False
 
         To make life more pleasant when returning deferred values, use
         ``inlineCallbacks``, which many of the standard build hooks use:
 
         >>> @inlineCallbacks
         ... def pre_build_hook(self, player, builddata):
-        ...     returnValue((True, builddata))
+        ...     returnValue((True, builddata, False))
 
         This form makes it much easier to deal with asynchronous operations on
         the factory and world.
@@ -353,6 +399,20 @@ class IPostBuildHook(ISortedPlugin):
     def post_build_hook(player, coords, block):
         """
         Do things.
+
+        The coordinates for the given block have already been pre-adjusted.
+        """
+
+class IPreDigHook(ISortedPlugin):
+    """
+    Hook for actions to be taken as dig started.
+    """
+    def pre_dig_hook(player, coords, block):
+        """
+        The ``player`` a Player's protocol
+        The ``coords`` is block coords - x, y, z
+        The ``block`` is a block we going to dig
+        :returns: True to cancel the dig action.
         """
 
 class IDigHook(ISortedPlugin):
