@@ -1,22 +1,21 @@
 from __future__ import division
 
 from gzip import GzipFile
-from itertools import chain
 import os
 from StringIO import StringIO
 from struct import pack, unpack
 from urlparse import urlparse
 
-from numpy import array, fromstring, uint8
+from numpy import array, fromstring
 
 from twisted.python import log
 from twisted.python.filepath import FilePath
 from zope.interface import implements, classProvides
 
+from bravo.beta.structures import Slot
 from bravo.entity import entities, tiles
 from bravo.errors import SerializerReadException, SerializerWriteException
 from bravo.ibravo import ISerializer, ISerializerFactory
-from bravo.inventory import Slot
 from bravo.location import Location
 from bravo.nbt import NBTFile
 from bravo.nbt import TAG_Compound, TAG_List, TAG_Byte_Array, TAG_String
@@ -360,9 +359,9 @@ class Alpha(object):
         # These are designed to raise if there are any issues, but still be
         # speedy.
         chunk.blocks = fromstring(level["Blocks"].value,
-            dtype=uint8).reshape(chunk.blocks.shape)
+            dtype="uint8").reshape(chunk.blocks.shape)
         chunk.heightmap = fromstring(level["HeightMap"].value,
-            dtype=uint8).reshape(chunk.heightmap.shape)
+            dtype="uint8").reshape(chunk.heightmap.shape)
         chunk.blocklight = array(unpack_nibbles(
             level["BlockLight"].value)).reshape(chunk.blocklight.shape)
         chunk.metadata = array(unpack_nibbles(
@@ -447,7 +446,6 @@ class Alpha(object):
 
         for item in tag.tags:
             slot = item["Slot"].value
-            slot = inventory.decode_slot(slot)
             items[slot] = Slot(item["id"].value,
                 item["Damage"].value, item["Count"].value)
 
@@ -456,13 +454,10 @@ class Alpha(object):
     def _save_inventory_to_tag(self, inventory):
         tag = TAG_List(type=TAG_Compound)
 
-        for i, item in enumerate(chain(inventory.crafted,
-            inventory.crafting, inventory.armor, inventory.storage,
-            inventory.holdables)):
+        for slot, item in enumerate(inventory.save_to_list()):
             if item is not None:
                 d = TAG_Compound()
                 id, damage, count = item
-                slot = inventory.encode_slot(i)
                 d["id"] = TAG_Short(id)
                 d["Damage"] = TAG_Short(damage)
                 d["Count"] = TAG_Byte(count)
