@@ -1,7 +1,7 @@
 from zope.interface import implements
 
 from bravo.blocks import blocks
-from bravo.ibravo import IPreBuildHook, IDigHook
+from bravo.ibravo import IPostBuildHook, IDigHook
 
 from bravo.parameters import factory
 
@@ -12,7 +12,7 @@ tracks_allowed_on = set([
     blocks["clay"].slot,
     blocks["coal-ore"].slot,
     blocks["cobblestone"].slot,
-    blocks["diamond"].slot,
+    blocks["diamond-block"].slot,
     blocks["diamond-ore"].slot,
     blocks["dirt"].slot,
     blocks["double-step"].slot,
@@ -25,7 +25,7 @@ tracks_allowed_on = set([
     blocks["iron"].slot,
     blocks["iron-ore"].slot,
     blocks["jack-o-lantern"].slot,
-    blocks["lapis-lazuli"].slot,
+    blocks["lapis-lazuli-block"].slot,
     blocks["lapis-lazuli-ore"].slot,
     blocks["leaves"].slot,
     blocks["lightstone"].slot,
@@ -60,11 +60,11 @@ class Tracks(object):
     Build and dig hooks for mine cart tracks.
     """
 
-    implements(IPreBuildHook, IDigHook)
+    implements(IPostBuildHook, IDigHook)
 
     name = "tracks"
 
-    def pre_build_hook(self, player, builddata):
+    def post_build_hook(self, player, coords, block):
         """
         Uses the players location yaw relative to the building position to
         place the tracks. This allows building straight tracks as well as
@@ -75,20 +75,16 @@ class Tracks(object):
         adjusted for placement and the face has no meaning.
         """
 
-        # XXX I need to be a post hook
-        # XXX I don't handle my Deferreds correctly
-        # XXX I need tests so that the above doesn't happen again
-
-        block, metadata, x, y, z, face = builddata
+        x, y, z = coords
         world = factory.world
 
         # Handle tracks only
         if block.slot != blocks["tracks"].slot:
-            return True, builddata
+            return
 
         # Check for correct underground
-        if world.get_block((x, y - 1, z)) not in tracks_allowed_on:
-            return False, builddata
+        if world.sync_get_block((x, y - 1, z)) not in tracks_allowed_on:
+            return
 
         # Use facing direction of player to set correct track tile
         yaw = player.location.yaw
@@ -101,37 +97,53 @@ class Tracks(object):
         elif 300 < yaw < 330:
             metadata = CORNER_NE
         elif 60 <= yaw <= 120 or 240 <= yaw <= 300:
-            # north or south
-            if world.get_block((x - 1, y + 1, z)) == blocks["tracks"].slot:
+            # North and south ascending tracks, if there are already tracks to
+            # the north or south.
+            if (world.sync_get_block((x - 1, y + 1, z)) ==
+                blocks["tracks"].slot):
                 metadata = ASCEND_N
-            elif world.get_block((x + 1, y + 1, z)) == blocks["tracks"].slot:
+            elif (world.sync_get_block((x + 1, y + 1, z)) ==
+                  blocks["tracks"].slot):
                 metadata = ASCEND_S
             else:
                 metadata = FLAT_NS
-            # check and adjust ascending tracks
-            if world.get_block((x - 1, y - 1, z)) == blocks["tracks"].slot:
-                if world.get_metadata((x - 1, y - 1, z)) == FLAT_NS:
-                    world.set_metadata((x - 1, y - 1, z), ASCEND_S)
-            if world.get_block((x + 1, y - 1, z)) == blocks["tracks"].slot:
-                if world.get_metadata((x + 1, y - 1, z)) == FLAT_NS:
-                    world.set_metadata((x + 1, y - 1, z), ASCEND_N)
-        else: # (0, 30) or (330, 0)
+
+            # If there are tracks to the north or south on the next Z-level
+            # down, they should be adjusted to ascend to this level.
+            target = x - 1, y - 1, z
+            if (world.sync_get_block(target) == blocks["tracks"].slot
+                and world.sync_get_metadata(target) == FLAT_NS):
+                world.sync_set_metadata(target, ASCEND_S)
+
+            target = x + 1, y - 1, z
+            if (world.sync_get_block(target) == blocks["tracks"].slot
+                and world.sync_get_metadata(target) == FLAT_NS):
+                world.sync_set_metadata(target, ASCEND_N)
+        # And this last range is east/west.
+        else:
             # east or west
-            if world.get_block((x, y + 1, z + 1)) == blocks["tracks"].slot:
+            if (world.sync_get_block((x, y + 1, z + 1)) ==
+                blocks["tracks"].slot):
                 metadata = ASCEND_W
-            elif world.get_block((x, y + 1, z - 1)) == blocks["tracks"].slot:
+            elif (world.sync_get_block((x, y + 1, z - 1)) ==
+                  blocks["tracks"].slot):
                 metadata = ASCEND_E
             else:
                 metadata = FLAT_EW
+
             # check and adjust ascending tracks
-            if world.get_block((x, y - 1, z - 1)) == blocks["tracks"].slot:
-                if world.get_metadata((x, y - 1, z - 1)) == FLAT_EW:
-                    world.set_metadata((x, y - 1, z - 1), ASCEND_W)
-            if world.get_block((x, y - 1, z + 1)) == blocks["tracks"].slot:
-                if world.get_metadata((x, y - 1, z + 1)) == FLAT_EW:
-                    world.set_metadata((x, y - 1, z + 1), ASCEND_E)
-        builddata = builddata._replace(metadata=metadata)
-        return True, builddata
+            target = x, y - 1, z - 1
+            if (world.sync_get_block(target) == blocks["tracks"].slot
+                and world.sync_get_metadata(target) == FLAT_EW):
+                world.sync_set_metadata(target, ASCEND_W)
+
+            target = x, y - 1, z + 1
+            if (world.sync_get_block(target) == blocks["tracks"].slot
+                and world.sync_get_metadata(target) == FLAT_EW):
+                world.sync_set_metadata(target, ASCEND_E)
+
+        # And finally, set the new metadata.
+        world.sync_set_metadata((x, y, z), metadata)
 
     def dig_hook(self, chunk, x, y, z, block):
         """
