@@ -1,23 +1,35 @@
 from twisted.trial import unittest
 
+from twisted.internet import reactor
+from twisted.internet.task import deferLater
+
 from construct import Container
 
+from bravo.beta.protocol import BetaServerProtocol, BravoProtocol
 from bravo.errors import BetaClientError
-import bravo.protocols.beta
 
 class FakeTransport(object):
 
     data = []
+    lost = False
 
     def write(self, data):
         self.data.append(data)
 
+    def loseConnection(self):
+        self.lost = True
+
 class TestBetaServerProtocol(unittest.TestCase):
 
     def setUp(self):
-        self.p = bravo.protocols.beta.BetaServerProtocol()
+        self.p = BetaServerProtocol()
         self.p.transport = FakeTransport()
 
+    def tearDown(self):
+        # Stop the connection timeout.
+        if self.p._TimeoutMixin__timeoutCall:
+            self.p._TimeoutMixin__timeoutCall.cancel()
+
     def test_trivial(self):
         pass
 
@@ -87,12 +99,10 @@ class TestBetaServerProtocol(unittest.TestCase):
         The protocol should emit a health update when its health changes.
         """
 
-        # Health packet, 19 health
-        expected = "\x08\x00\x13"
-
+        self.p.transport.data = []
         self.p.health = 19
         self.assertEqual(len(self.p.transport.data), 1)
-        self.assertEqual(self.p.transport.data[0], expected)
+        self.assertTrue(self.p.transport.data[0].startswith("\x08"))
 
     def test_health_no_change(self):
         """
@@ -100,14 +110,30 @@ class TestBetaServerProtocol(unittest.TestCase):
         issued.
         """
 
+        self.p.transport.data = []
         self.p.health = 20
         self.assertFalse(self.p.transport.data)
 
+    def test_connection_timeout(self):
+        """
+        Connections should time out after 30 seconds.
+        """
+
+        def cb():
+            self.assertTrue(self.p.transport.lost)
+
+        d = deferLater(reactor, 31, cb)
+        return d
+
 
 class TestBravoProtocol(unittest.TestCase):
 
     def setUp(self):
-        self.p = bravo.protocols.beta.BravoProtocol("unittest")
+        self.p = BravoProtocol("unittest")
+
+    def tearDown(self):
+        if self.p._TimeoutMixin__timeoutCall:
+            self.p._TimeoutMixin__timeoutCall.cancel()
 
     def test_trivial(self):
         pass
