@@ -1,50 +1,42 @@
+from __future__ import division
+
 from twisted.trial import unittest
 
-import bravo.blocks
-from bravo.blocks import parse_block
+from bravo.blocks import blocks, items, parse_block
 
 class TestBlockNames(unittest.TestCase):
 
-    def setUp(self):
-        self.bn = set(bravo.blocks.block_names)
-        self.ins = set(bravo.blocks.item_names)
-        self.sin = set(bravo.blocks.special_item_names)
-
-    def test_trivial(self):
-        pass
-
     def test_unique_blocks_and_items(self):
-        self.assertTrue(self.bn.isdisjoint(self.ins), repr(self.bn & self.ins))
-
-    test_unique_blocks_and_items.todo = "Needs love and disambiguation"
-
-    def test_unique_blocks_and_special_items(self):
-        self.assertTrue(self.bn.isdisjoint(self.sin), repr(self.bn & self.sin))
-
-    def test_unique_items_and_special_items(self):
-        self.assertTrue(self.ins.isdisjoint(self.sin), repr(self.ins & self.sin))
+        block_names = set(blocks)
+        item_names = set(items)
+        self.assertTrue(block_names.isdisjoint(item_names),
+            repr(block_names & item_names))
 
 class TestBlockQuirks(unittest.TestCase):
 
     def test_ice_no_drops(self):
-        self.assertEqual(bravo.blocks.blocks["ice"].drop,
-            bravo.blocks.blocks["air"].slot)
+        self.assertEqual(blocks["ice"].drop, blocks["air"].key)
+
+    def test_lapis_ore_drops(self):
+        self.assertEqual(blocks["lapis-lazuli-ore"].drop,
+            items["lapis-lazuli"].key)
+        self.assertEqual(blocks["lapis-lazuli-ore"].quantity, 6)
 
     def test_sapling_drop_rate(self):
-        self.assertAlmostEqual(bravo.blocks.blocks["leaves"].ratio, 1/9.0)
+        self.assertAlmostEqual(blocks["leaves"].ratio, 1 / 9)
 
     def test_unbreakable_bedrock(self):
-        self.assertFalse(bravo.blocks.blocks["bedrock"].breakable)
+        self.assertFalse(blocks["bedrock"].breakable)
 
     def test_ladder_orientation(self):
-        self.assertTrue(bravo.blocks.blocks["ladder"].orientable())
-        self.assertEqual(bravo.blocks.blocks["ladder"].orientation("+x"), 0x5)
+        self.assertTrue(blocks["ladder"].orientable())
+        self.assertEqual(blocks["ladder"].orientation("+x"), 0x5)
 
     def test_ladder_face(self):
-        self.assertEqual(bravo.blocks.blocks["ladder"].face(0x5), "+x")
+        self.assertEqual(blocks["ladder"].face(0x5), "+x")
 
     def test_grass_secondary(self):
-        self.assertEqual(bravo.blocks.blocks["grass"].key[1], 0)
+        self.assertEqual(blocks["grass"].key[1], 0)
 
 class TestParseBlock(unittest.TestCase):
 
