@@ -4,8 +4,9 @@ import random
 import sys
 import weakref
 
-from numpy import fromstring, uint8
+from numpy import fromstring
 
+from twisted.internet import reactor
 from twisted.internet.defer import (inlineCallbacks, maybeDeferred,
                                     returnValue, succeed)
 from twisted.internet.task import coiterate, LoopingCall
@@ -13,13 +14,14 @@ from twisted.python import log
 
 from bravo.chunk import Chunk
 from bravo.config import configuration
-from bravo.entity import Player
+from bravo.entity import Player, Furnace
 from bravo.errors import ChunkNotLoaded, SerializerReadException
 from bravo.ibravo import ISerializer, ISerializerFactory
 from bravo.plugin import (retrieve_named_plugins, verify_plugin,
     PluginException)
 from bravo.utilities.coords import split_coords
 from bravo.utilities.temporal import PendingEvent
+from bravo.mobmanager import MobManager
 
 def coords_to_chunk(f):
     """
@@ -72,6 +74,14 @@ class World(object):
     exactly one file on disk. Worlds also contain saved player data.
     """
 
+    factory = None
+    """
+    The factory managing this world.
+
+    Worlds do not need to be owned by a factory, but will not callback to
+    surrounding objects without an owner.
+    """
+
     season = None
     """
     The current `ISeason`.
@@ -173,6 +183,9 @@ class World(object):
             (world_url, self.serializer.name))
         log.msg("Using Ampoule: %s" % self.async)
 
+        self.mob_manager = MobManager() # XXX Put this in init or here?
+        self.mob_manager.world = self # XXX  Put this in the managers constructor?
+
     def stop(self):
         """
         Stop managing the world.
@@ -295,10 +308,27 @@ class World(object):
         # Thus, it should start out undamaged.
         chunk.clear_damage()
 
+        # Skip some of the spendier scans if we have no factory; for example,
+        # if we are generating chunks offline.
+        if not self.factory:
+            return chunk
+
         # Register the chunk's entities with our parent factory.
         for entity in chunk.entities:
+            if hasattr(entity,'loop'):
+                print "Started mob!"
+                self.mob_manager.start_mob(entity)
+            else:
+                print "I have no loop"
             self.factory.register_entity(entity)
 
+        # Scan the chunk for burning furnaces and update thir processes
+        for coords, tile in chunk.tiles.iteritems():
+            if type(tile) == Furnace and tile.burntime != 0:
+                x, y, z = coords
+                coords = chunk.x, x, chunk.z, z, y
+                reactor.callLater(2, self.factory.furnace_manager.update, coords)
+
         # Return the chunk, in case we are in a Deferred chain.
         return chunk
 
@@ -325,7 +355,8 @@ class World(object):
         if chunk.populated:
             self.chunk_cache[x, z] = chunk
             self.postprocess_chunk(chunk)
-            #self.factory.scan_chunk(chunk)
+            if self.factory:
+                self.factory.scan_chunk(chunk)
             returnValue(chunk)
 
         if self.async:
@@ -342,15 +373,15 @@ class World(object):
             # Get chunk data into our chunk object.
             def fill_chunk(kwargs):
                 chunk.blocks = fromstring(kwargs["blocks"],
-                    dtype=uint8).reshape(chunk.blocks.shape)
+                    dtype="uint8").reshape(chunk.blocks.shape)
                 chunk.heightmap = fromstring(kwargs["heightmap"],
-                    dtype=uint8).reshape(chunk.heightmap.shape)
+                    dtype="uint8").reshape(chunk.heightmap.shape)
                 chunk.metadata = fromstring(kwargs["metadata"],
-                    dtype=uint8).reshape(chunk.metadata.shape)
+                    dtype="uint8").reshape(chunk.metadata.shape)
                 chunk.skylight = fromstring(kwargs["skylight"],
-                    dtype=uint8).reshape(chunk.skylight.shape)
+                    dtype="uint8").reshape(chunk.skylight.shape)
                 chunk.blocklight = fromstring(kwargs["blocklight"],
-                    dtype=uint8).reshape(chunk.blocklight.shape)
+                    dtype="uint8").reshape(chunk.blocklight.shape)
 
                 return chunk
             d.addCallback(fill_chunk)
@@ -369,7 +400,8 @@ class World(object):
         # This one is for our return value.
         retval = pe.deferred()
         # This one is for scanning the chunk for automatons.
-        #pe.deferred().addCallback(self.factory.scan_chunk)
+        if self.factory:
+            pe.deferred().addCallback(self.factory.scan_chunk)
         self._pending_chunks[x, z] = pe
 
         def pp(chunk):
@@ -550,3 +582,13 @@ class World(object):
         """
 
         chunk.dirty = True
+
+    @sync_coords_to_chunk
+    def sync_request_chunk(self, chunk, coords):
+        """
+        Get an unknown chunk.
+
+        :returns: a ``Deferred`` with the requested value
+        """
+
+        return chunk
